from prowler.lib.check.models import Check, Check_Report_AWS
from prowler.providers.aws.services.rds.rds_client import rds_client


class rds_instance_event_subscription_parameter_groups(Check):
    def execute(self):
        findings = []
        if rds_client.provider.scan_unused_services or rds_client.db_instances:
            for db_event in rds_client.db_event_subscriptions:
                report = Check_Report_AWS(self.metadata())
                report.status = "FAIL"
                report.status_extended = "RDS parameter group event categories of configuration change is not subscribed."
                report.resource_id = rds_client.audited_account
                report.resource_arn = rds_client._get_rds_arn_template(db_event.region)
                report.region = db_event.region
                report.resource_tags = []
                if db_event.source_type == "db-parameter-group" and db_event.enabled:
                    if db_event.event_list == [] or db_event.event_list == [
                        "configuration change",
                    ]:
                        report.resource_id = db_event.id
                        report.resource_arn = db_event.arn
                        report.resource_tags = db_event.tags
                        report.status = "PASS"
                        report.status_extended = (
                            "RDS parameter group events are subscribed."
                        )
                findings.append(report)

        return findings



from prowler.lib.check.models import Check, Check_Report_Azure
from prowler.providers.azure.services.sqlserver.sqlserver_client import sqlserver_client


class sqlserver_azuread_administrator_enabled(Check):
    def execute(self) -> Check_Report_Azure:
        findings = []
        for subscription, sql_servers in sqlserver_client.sql_servers.items():
            for sql_server in sql_servers:
                report = Check_Report_Azure(self.metadata())
                report.subscription = subscription
                report.status = "PASS"
                report.location = sql_server.location
                report.status_extended = f"SQL Server {sql_server.name} from subscription {subscription} has an Active Directory administrator."
                report.resource_name = sql_server.name
                report.resource_id = sql_server.id

                if (
                    sql_server.administrators is None
                    or sql_server.administrators.administrator_type != "ActiveDirectory"
                ):
                    report.status = "FAIL"
                    report.status_extended = f"SQL Server {sql_server.name} from subscription {subscription} does not have an Active Directory administrator."

                findings.append(report)

        return findings
